@@ -58,6 +58,7 @@ from .resources import (
     Conversation,
     ConversationDataSource,
     ConversationLevelSentiment,
+    ConversationParticipant,
     DialogflowIntent,
     DialogflowInteractionData,
     DialogflowSource,
@@ -131,6 +132,7 @@ __all__ = (
     "Conversation",
     "ConversationDataSource",
     "ConversationLevelSentiment",
+    "ConversationParticipant",
     "DialogflowIntent",
     "DialogflowInteractionData",
     "DialogflowSource",
