@@ -111,8 +111,48 @@ class CalculateStatsResponse(proto.Message):
             respective number of matches in the set of conversations.
             Key has the format:
             ``projects/<Project ID>/locations/<Location ID>/issueModels/<Issue Model ID>/issues/<Issue ID>``
+        conversation_count_time_series (google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.TimeSeries):
+            A time series representing the count of
+            conversations created over time that match that
+            requested filter criteria.
     """
 
+    class TimeSeries(proto.Message):
+        r"""A time series representing conversations over time.
+        Attributes:
+            interval_duration (google.protobuf.duration_pb2.Duration):
+                The duration of each interval.
+            points (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.TimeSeries.Interval]):
+                An ordered list of intervals from earliest to
+                latest, where each interval represents the
+                number of conversations that transpired during
+                the time window.
+        """
+
+        class Interval(proto.Message):
+            r"""A single interval in a time series.
+            Attributes:
+                start_time (google.protobuf.timestamp_pb2.Timestamp):
+                    The start time of this interval.
+                conversation_count (int):
+                    The number of conversations created in this
+                    interval.
+            """
+
+            start_time = proto.Field(
+                proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+            )
+            conversation_count = proto.Field(proto.INT32, number=2,)
+
+        interval_duration = proto.Field(
+            proto.MESSAGE, number=1, message=duration_pb2.Duration,
+        )
+        points = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message="CalculateStatsResponse.TimeSeries.Interval",
+        )
+
     average_duration = proto.Field(
         proto.MESSAGE, number=1, message=duration_pb2.Duration,
     )
@@ -121,6 +161,9 @@ class CalculateStatsResponse(proto.Message):
     smart_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=4,)
     custom_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=5,)
     issue_matches = proto.MapField(proto.STRING, proto.INT32, number=6,)
+    conversation_count_time_series = proto.Field(
+        proto.MESSAGE, number=7, message=TimeSeries,
+    )
 
 
 class CreateAnalysisOperationMetadata(proto.Message):
@@ -384,6 +427,11 @@ class ExportInsightsDataRequest(proto.Message):
     class BigQueryDestination(proto.Message):
         r"""A BigQuery Table Reference.
         Attributes:
+            project_id (str):
+                A project ID or number. If specified, then
+                export will attempt to write data to this
+                project instead of the resource project.
+                Otherwise, the resource project will be used.
             dataset (str):
                 Required. The name of the BigQuery dataset that the snapshot
                 result should be exported to. If this dataset does not
@@ -394,6 +442,7 @@ class ExportInsightsDataRequest(proto.Message):
                 returns an INVALID_ARGUMENT error.
         """
 
+        project_id = proto.Field(proto.STRING, number=3,)
         dataset = proto.Field(proto.STRING, number=1,)
         table = proto.Field(proto.STRING, number=2,)
 
